------------------------------------------------------------------------------
--                              Ada Web Server                              --
--                                                                          --
--                         Copyright (C) 2000-2001                          --
--                                ACT-Europe                                --
--                                                                          --
--  Authors: Dmitriy Anisimkov - Pascal Obry                                --
--                                                                          --
--  This library is free software; you can redistribute it and/or modify    --
--  it under the terms of the GNU General Public License as published by    --
--  the Free Software Foundation; either version 2 of the License, or (at   --
--  your option) any later version.                                         --
--                                                                          --
--  This library is distributed in the hope that it will be useful, but     --
--  WITHOUT ANY WARRANTY; without even the implied warranty of              --
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       --
--  General Public License for more details.                                --
--                                                                          --
--  You should have received a copy of the GNU General Public License       --
--  along with this library; if not, write to the Free Software Foundation, --
--  Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.          --
--                                                                          --
--  As a special exception, if other files instantiate generics from this   --
--  unit, or you link this unit with other files to produce an executable,  --
--  this  unit  does not  by itself cause  the resulting executable to be   --
--  covered by the GNU General Public License. This exception does not      --
--  however invalidate any other reasons why the executable file  might be  --
--  covered by the  GNU Public License.                                     --
------------------------------------------------------------------------------

--  $Id: res_demo.adb,v 1.1 2002/06/23 16:38:09 obry Exp $

--  A standalone Web server, with pages embedded into the executable.

with Ada.Text_IO;

with AWS.Response;
with AWS.Server;
with AWS.Status;
with AWS.Default;
with AWS.Messages;

with rdemo; -- this package is generated by AWSRes
pragma Warnings (Off, rdemo);

procedure Res_Demo is

   WS : AWS.Server.HTTP;

   function RD_CB (Request : in AWS.Status.Data)
      return AWS.Response.Data
   is
      URI : constant String := AWS.Status.URI (Request);
   begin
      if URI = "/img" then
         return AWS.Response.File ("image/png", "adains.png");
      elsif URI = "/page" then
         return AWS.Response.File ("text/html", "page3.html");
      else
         return AWS.Response.Acknowledge (AWS.Messages.S404, "<p>Not found !");
      end if;
   end RD_CB;

begin
   Ada.Text_IO.Put_Line
     ("Call me on port"
      & Positive'Image (AWS.Default.Server_Port)
      & ", I will stop in 60 seconds...");

   AWS.Server.Start (WS, "Res Demo",
                     Max_Connection => 1,
                     Callback       => RD_CB'Unrestricted_Access);

   delay 60.0;

   AWS.Server.Shutdown (WS);
end Res_Demo;
